@@ -20,7 +20,7 @@ has '_content' => (is =>'rw');
 sub timestamp_added
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --diff-filter=A --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --diff-filter=A --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -36,7 +36,7 @@ sub timestamp_added
 sub timestamp_last
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -52,7 +52,7 @@ sub timestamp_last
 sub committer
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -153,7 +153,7 @@ Git::LowLevel::Blob - class representing a GIT Blow Object
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 DESCRIPTION
 
