@@ -23,7 +23,7 @@ has 'changed' => (is => 'rw', isa => 'Bool', default=>0);
 sub timestamp_added
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --diff-filter=A --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --diff-filter=A --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -39,7 +39,7 @@ sub timestamp_added
 sub timestamp_last
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -55,7 +55,7 @@ sub timestamp_last
 sub committer
 {
   my $self  = shift;
-  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- " . $self->path . " 2>/dev/null");
+  my $help = readpipe($self->repository->gitcmd() . " log --follow --date=raw " . $self->reference->reference . " -- \"" . $self->path . "\" 2>/dev/null");
   my @lines = split /\n/,$help;
   for my $line (@lines)
   {
@@ -199,7 +199,6 @@ sub save
   }
 
   if ($self->changed()) {
-    print "STR:" . $str . "\n";
     my $help = readpipe("/bin/echo -e \"" . $str. "\" | " .  $self->repository->gitcmd() . " mktree --batch ");
     chomp($help);
     $self->hash($help);
@@ -251,7 +250,7 @@ Git::LowLevel::Tree - class representing a tree object in a GIT Repository
 
 =head1 VERSION
 
-version 0.2
+version 0.3
 
 =head1 ATTRIBUTES
 
